@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: functions.lisp 10917 2006-04-18 00:07:09Z kevin $
+;;;; $Id: functions.lisp 11214 2006-10-10 14:35:39Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2005 by Kevin M. Rosenberg
 ;;;;
@@ -137,6 +137,7 @@
 (defmacro def-function (names args &key module returning)
   (multiple-value-bind (lisp-args out processed)
       (preprocess-args args)
+    (declare (ignorable lisp-args processed))
     (if (= (length out) 0)
 	`(%def-function ,names ,args 
 	  ,@(if module (list :module module) (values))
@@ -197,7 +198,7 @@
        ,@(if module (list :module module) (values))
        :result-type ,result-type
       :language :ansi-c
-       #-macosx :calling-convention #-macosx :cdecl)
+       #+:win32 :calling-convention #+:win32 :cdecl)
     #+digitool
     `(eval-when (:compile-toplevel :load-toplevel :execute)
        (ccl:define-entry-point (,lisp-name ,foreign-name)
