@@ -7,7 +7,7 @@
 ;;;; Programmer:    Kevin M. Rosenberg
 ;;;; Date Started:  Feb 2002
 ;;;;
-;;;; $Id: libraries.lisp 10953 2006-05-17 15:14:07Z kevin $
+;;;; $Id: libraries.lisp 11087 2006-09-03 02:31:58Z kevin $
 ;;;;
 ;;;; This file, part of UFFI, is Copyright (c) 2002-2005 by Kevin M. Rosenberg
 ;;;;
@@ -20,9 +20,9 @@
 
 (defun default-foreign-library-type ()
   "Returns string naming default library type for platform"
-  #+(or win32 mswindows) "dll"
+  #+(or win32 cygwin mswindows) "dll"
   #+(or macosx darwin ccl-5.0) "dylib"
-  #-(or win32 mswindows macosx darwin ccl-5.0) "so"
+  #-(or win32 cygwin mswindows macosx darwin ccl-5.0) "so"
 )
 
 (defun foreign-library-types ()
